# eric7.UI.VersionsDialog

Module implementing a dialog to show the versions of various components.

### Global Attributes

None

### Classes

VersionsDialog | Class implementing a dialog to show the versions of various components.

### Functions

None

## VersionsDialog

Class implementing a dialog to show the versions of various components.

### Derived from

QDialog, Ui_VersionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

VersionsDialog | Constructor
__checkForUpdate | Private slot to check, if updates of PyQt6 packages or the eric-ide package are available.

### Static Methods

None

#### VersionsDialog (Constructor)

VersionsDialog(parent, title, text)

Constructor

parent (UserInterface)
  reference to the parent widget
title (str)
  dialog title
text (str)
  versions text to be shown

#### VersionsDialog.__checkForUpdate

__checkForUpdate()

Private slot to check, if updates of PyQt6 packages or the eric-ide package are available.

Up